==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiCore/QBasicMutex_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qmutex.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBasicMutex(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBasicMutex")
    QBasicMutex *_ptr = reinterpret_cast<QBasicMutex *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBasicMutex()
void __qt_construct_QBasicMutex_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBasicMutex()")
    Q_UNUSED(__java_arguments)
    QBasicMutex *__qt_this = new(__qtjambi_ptr) QBasicMutex();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QBasicMutex
void __qt_destruct_QBasicMutex(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBasicMutex")
    reinterpret_cast<QBasicMutex*>(ptr)->~QBasicMutex();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBasicMutex::QBasicMutex()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBasicMutex_initialize_1native__Lio_qt_core_QBasicMutex_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBasicMutex::QBasicMutex()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBasicMutex_0, sizeof(QBasicMutex), typeid(QBasicMutex), false, &deleter_QBasicMutex, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBasicMutex::lock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBasicMutex_lock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBasicMutex *__qt_this = QtJambiAPI::objectFromNativeId<QBasicMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBasicMutex::lock()", __qt_this)
        __qt_this->lock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBasicMutex::tryLock()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBasicMutex_tryLock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QBasicMutex *__qt_this = QtJambiAPI::objectFromNativeId<QBasicMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBasicMutex::tryLock()", __qt_this)
        __java_return_value = __qt_this->tryLock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBasicMutex::unlock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBasicMutex_unlock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBasicMutex *__qt_this = QtJambiAPI::objectFromNativeId<QBasicMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBasicMutex::unlock()", __qt_this)
        __qt_this->unlock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QBasicMutex(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QBasicMutex>("QBasicMutex", "io/qt/core/QBasicMutex");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBasicMutex, {
        ConstructorInfo(&__qt_construct_QBasicMutex_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBasicMutex);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiCore/QBasicMutex_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qmutex.h>
#include <QtCore/QVariant>
#include <QtCore/qdeadlinetimer.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QBasicMutex(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QBasicMutex")
    QBasicMutex *_ptr = reinterpret_cast<QBasicMutex *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QBasicMutex()
void __qt_construct_QBasicMutex(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QBasicMutex()")
    Q_UNUSED(__java_arguments)
    QBasicMutex *__qt_this = new(__qtjambi_ptr) QBasicMutex();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QBasicMutex::QBasicMutex()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBasicMutex_initialize_1native__Lio_qt_core_QBasicMutex_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QBasicMutex::QBasicMutex()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QBasicMutex, sizeof(QBasicMutex), typeid(QBasicMutex), false, &deleter_QBasicMutex, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QBasicMutex
void __qt_destruct_QBasicMutex(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QBasicMutex")
    reinterpret_cast<QBasicMutex*>(ptr)->~QBasicMutex();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QBasicMutex::lock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBasicMutex_lock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBasicMutex *__qt_this = QtJambiAPI::objectFromNativeId<QBasicMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBasicMutex::lock()", __qt_this)
        __qt_this->lock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QBasicMutex::tryLock()
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBasicMutex_tryLock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QBasicMutex *__qt_this = QtJambiAPI::objectFromNativeId<QBasicMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBasicMutex::tryLock()", __qt_this)
        __java_return_value = __qt_this->tryLock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QBasicMutex::unlock()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QBasicMutex_unlock_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QBasicMutex *__qt_this = QtJambiAPI::objectFromNativeId<QBasicMutex>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QBasicMutex::unlock()", __qt_this)
        __qt_this->unlock();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QBasicMutex(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QBasicMutex>("QBasicMutex", "io/qt/core/QBasicMutex");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QBasicMutex, {
        ConstructorInfo(&__qt_construct_QBasicMutex, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QBasicMutex);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
